suotar_exchange_details

Function suotar_exchange_details 

pub fn suotar_exchange_details(
    request: Option<&Value>,
    response: Option<&Value>,
) -> Value
Both sides of a Suotar exchange, scrubbed on construction so there is no way to build an unscrubbed details. The request is kept because the ledger row no longer reflects it after a retry.